@@ -10,7 +10,6 @@
 
 #include <KCalendarCore/ICalFormat>
 #include <KCalendarCore/MemoryCalendar>
-#include <kcontacts_version.h>
 
 #include <QDebug>
 #include <QFile>
@@ -72,7 +71,7 @@ private Q_SLOTS:
 
         MemoryCalendar::Ptr refCal(new MemoryCalendar(QTimeZone::systemTimeZone()));
         ICalFormat format;
-        format.load(refCal, icalFile);
+        QVERIFY(format.load(refCal, icalFile));
 
         const auto refEvents = refCal->rawEvents(KCalendarCore::EventSortStartDate, KCalendarCore::SortDirectionAscending);
         QCOMPARE(refEvents.size(), 1);
@@ -103,10 +102,8 @@ private Q_SLOTS:
         QCOMPARE(newEvent->dtStart(), refEvent->dtStart());
         QCOMPARE(newEvent->dtEnd(), refEvent->dtEnd());
         QCOMPARE(newEvent->customProperty("KITINERARY", "RESERVATION"), refEvent->customProperty("KITINERARY", "RESERVATION"));
-#if KContacts_VERSION >= QT_VERSION_CHECK(5, 92, 0)
         QCOMPARE(newEvent->description(), refEvent->description());
         QVERIFY(*newEvent == *refEvent);
-#endif
     }
 
     void testFindEvent_data()
@@ -144,7 +141,7 @@ private Q_SLOTS:
 
         MemoryCalendar::Ptr refCal(new MemoryCalendar(QTimeZone::systemTimeZone()));
         ICalFormat format;
-        format.load(refCal, icalFile);
+        QVERIFY(format.load(refCal, icalFile));
 
         const auto events = CalendarHandler::findEvents(refCal, postproc.result().at(0));
         QCOMPARE(events.size(), 1);
@@ -161,7 +158,7 @@ private Q_SLOTS:
 
         MemoryCalendar::Ptr refCal(new MemoryCalendar(QTimeZone::systemTimeZone()));
         ICalFormat format;
-        format.load(refCal, QStringLiteral(SOURCE_DIR "/calendarhandlerdata/to-be-cancelled.ics"));
+        QVERIFY(format.load(refCal, QStringLiteral(SOURCE_DIR "/calendarhandlerdata/to-be-cancelled.ics")));
 
         const auto events = CalendarHandler::findEvents(refCal, cancel);
         QCOMPARE(events.size(), 2);
