@@ -40,6 +40,8 @@ bool TrainStationDbGenerator::generate(QIODevice *out)
      || !fetch("P8448", "benerail", m_benerailIdMap)
      || !fetch("P238", "iata", m_iataMap)
      || !fetch("P4803", "amtrak", m_amtrakMap)
+     || !fetch("P10653", "viarail", m_viaRailMap)
+     || !fetch("P4755", "uk", m_ukMap)
      || !fetchIndianRailwaysStationCode()
      || !fetchFinishStationCodes()
     ) {
@@ -68,6 +70,8 @@ namespace KnowledgeDb {
     writeIdMap(out, m_benerailIdMap, "benerail", "BenerailStationId");
     writeIdMap(out, m_iataMap, "iata", "IataCode");
     writeIdMap(out, m_amtrakMap, "amtrak", "AmtrakStationCode");
+    writeIdMap(out, m_viaRailMap, "viarail", "ViaRailStationCode");
+    writeIdMap(out, m_ukMap, "uk", "UKRailwayStationCode");
     writeIndianRailwaysMap(out);
     writeVRMap(out);
     out->write(R"(
@@ -83,11 +87,12 @@ template<typename Id>
 bool TrainStationDbGenerator::fetch(const char *prop, const char *name, std::map<Id, QUrl> &idMap)
 {
     const auto stationArray = WikiData::query(QLatin1String(R"(
-        SELECT DISTINCT ?station ?stationLabel ?id ?coord ?replacedBy WHERE {
+        SELECT DISTINCT ?station ?stationLabel ?id ?coord ?replacedBy ?dateOfOfficialClosure WHERE {
             ?station (wdt:P31/wdt:P279*) wd:Q55488.
             ?station wdt:)") + QString::fromUtf8(prop) + QLatin1String(R"( ?id.
             OPTIONAL { ?station wdt:P625 ?coord. }
             OPTIONAL { ?station wdt:P1366 ?replacedBy. }
+            OPTIONAL { ?station wdt:P3999 ?dateOfOfficialClosure. }
             SERVICE wikibase:label { bd:serviceParam wikibase:language "en". }
         } ORDER BY (?station))"), QLatin1String("wikidata_trainstation_") + QString::fromUtf8(name) + QLatin1String(".json"));
     if (stationArray.isEmpty()) {
@@ -97,7 +102,7 @@ bool TrainStationDbGenerator::fetch(const char *prop, const char *name, std::map
 
     for (const auto &stationData : stationArray) {
         const auto stationObj = stationData.toObject();
-        if (stationObj.contains(QLatin1String("replacedBy"))) {
+        if (stationObj.contains(QLatin1String("replacedBy")) || stationObj.contains(QLatin1String("dateOfOfficialClosure"))) {
             continue;
         }
 
@@ -403,6 +408,8 @@ void TrainStationDbGenerator::printSummary()
     qDebug() << "VR (Finland) station code index:" << m_vrfiMap.size() << "elements";
     qDebug() << "IATA location code index:" << m_iataMap.size() << "elements";
     qDebug() << "Amtrak station code index:" << m_amtrakMap.size() << "elements";
+    qDebug() << "Via Rail station code index:" << m_viaRailMap.size() << "elements";
+    qDebug() << "UK railway station code index:" << m_ukMap.size() << "elements";
     qDebug() << "Identifier collisions:" << m_idConflicts;
     qDebug() << "Identifier format violations:" << m_idFormatViolations;
     qDebug() << "Coordinate conflicts:" << m_coordinateConflicts;
