@@ -136,7 +136,7 @@ void ExtractorFilter::setScope(Scope scope)
 
 static QString valueForJsonPath(const QJsonObject &obj, const QString &path)
 {
-    const auto pathSections = path.splitRef(QLatin1Char('.'));
+    const auto pathSections = QStringView(path).split(QLatin1Char('.'));
     QJsonValue v(obj);
     for (const auto &pathSection : pathSections) {
         if (!v.isObject()) {
