@@ -8,7 +8,7 @@
 
 #include "kitinerary_export.h"
 
-#include <QDate>
+#include <QDateTime>
 #include <QVector>
 
 #include <memory>
@@ -32,8 +32,8 @@ namespace IataBcbpParser
  *  @param externalIssueDate The date the boarding pass was issued (or a sufficiently close approximation).
  *  This is necessary as by default the BCBP data only contains day and month of the flight, not the year.
  */
-QVector<QVariant> parse(const QString &message, const QDate &externalIssueDate = QDate());
-KITINERARY_EXPORT QVector<QVariant> parse(const IataBcbp &bcbp, const QDate &contextDate);
+QVector<QVariant> parse(const QString &message, const QDateTime &externalIssueDateTime = QDateTime());
+KITINERARY_EXPORT QVector<QVariant> parse(const IataBcbp &bcbp, const QDateTime &contextDate);
 }
 
 }
