@@ -19,6 +19,7 @@
 
 #include <DateInfo.h>
 #include <PDFDoc.h>
+#include <PDFDocEncoding.h>
 #include <Stream.h>
 
 #include <cmath>
@@ -296,15 +297,34 @@ QDateTime PdfDocument::modificationTime() const
 #endif
 }
 
-QString PdfDocument::producer() const
+
+QString gooStringToUnicode(const std::unique_ptr<GooString> &s)
 {
-    std::unique_ptr<GooString> s(d->m_popplerDoc->getDocInfoProducer());
     if (!s) {
         return {};
     }
+
+    if (s->hasUnicodeMarker() || s->hasUnicodeMarkerLE()) {
+        return QString::fromUtf16(reinterpret_cast<const ushort*>(s->toStr().c_str()), s->toStr().size() / 2);
+    } else {
+        int len = 0;
+        std::unique_ptr<const char[]> utf16Data(pdfDocEncodingToUTF16(s->toStr(), &len));
+        return QString::fromUtf16(reinterpret_cast<const ushort*>(utf16Data.get()), len / 2);
+    }
+
     return QString::fromUtf8(s->c_str());
 }
 
+QString PdfDocument::title() const
+{
+    return gooStringToUnicode(d->m_popplerDoc->getDocInfoTitle());
+}
+
+QString PdfDocument::producer() const
+{
+    return gooStringToUnicode(d->m_popplerDoc->getDocInfoProducer());
+}
+
 QVariantList PdfDocument::pagesVariant() const
 {
     QVariantList l;
