@@ -4,6 +4,8 @@
     SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
+#include "../lib/asn1/berelement.h"
+#include "../lib/era/fcbticket.h"
 #include "../lib/era/ssbv1ticket.h"
 #include "../lib/era/ssbv2ticket.h"
 #include "../lib/era/ssbv3ticket.h"
@@ -12,7 +14,6 @@
 #include "../lib/uic9183/uic9183header.h"
 #include "../lib/uic9183/vendor0080vublockdata.h"
 #include "../lib/vdv/vdvticketcontent.h"
-#include "../lib/tlv/berelement.h"
 
 #include <kitinerary_version.h>
 
@@ -28,6 +29,7 @@
 #include <QDebug>
 #include <QFile>
 #include <QMetaProperty>
+#include <QSequentialIterable>
 
 #include <iostream>
 
@@ -38,16 +40,39 @@ using namespace KItinerary;
 template <typename T>
 static void dumpGadget(const T *gadget, const char* indent = "")
 {
-    if (!gadget) {
+    dumpGadget(gadget, &T::staticMetaObject, indent);
+}
+
+static void dumpGadget(const void *gadget, const QMetaObject *mo, const char* indent)
+{
+    if (!gadget || !mo) {
         return;
     }
-    for (auto i = 0; i < T::staticMetaObject.propertyCount(); ++i) {
-        const auto prop = T::staticMetaObject.property(i);
+    for (auto i = 0; i < mo->propertyCount(); ++i) {
+        const auto prop = mo->property(i);
         if (!prop.isStored()) {
             continue;
         }
         const auto value = prop.readOnGadget(gadget);
         std::cout << indent << prop.name() << ": " << qPrintable(value.toString()) << std::endl;
+        if (const auto childMo = QMetaType::metaObjectForType(value.userType())) {
+            QByteArray childIndent(indent);
+            childIndent.push_back(' ');
+            dumpGadget(value.constData(), childMo, childIndent.constData());
+        } else if (value.canConvert<QVariantList>() && value.type() != QVariant::String && value.type() != QVariant::ByteArray) {
+            auto iterable = value.value<QSequentialIterable>();
+            int idx = 0;
+            QByteArray childIndent(indent);
+            childIndent.append("  ");
+            for (const QVariant &v : iterable) {
+                if (QMetaType::metaObjectForType(v.userType())) {
+                    std::cout << indent << " [" << idx++ << "]:" << std::endl;
+                    dumpGadget(v.constData(), QMetaType::metaObjectForType(v.userType()), childIndent.constData());
+                } else {
+                    std::cout << indent << " [" << idx++ << "]: "  << qPrintable(v.toString()) << std::endl;
+                }
+            }
+        }
     }
 }
 
@@ -130,6 +155,9 @@ static void dumpUic9183(const QByteArray &data)
                           << " format: " << field.format() << "]: " << qPrintable(field.text())
                           << std::endl;
             }
+        } else if (block.isA<Fcb::UicRailTicketData>()) {
+            Fcb::UicRailTicketData fcb(block);
+            dumpGadget(&fcb, "  ");
         } else if (block.isA<Vendor0080BLBlock>()) {
             Vendor0080BLBlock vendor(block);
             dumpGadget(&vendor, "  ");
